import React, { useEffect, useRef } from 'react';
import { initializeApp, getApps } from 'firebase/app';
import { getMessaging, getToken, onMessage } from 'firebase/messaging';
import { Toast } from 'primereact/toast';
export var NotificationProvider = function (_a) {
    var firebaseConfig = _a.firebaseConfig, vapidKey = _a.vapidKey, children = _a.children;
    var toast = useRef(null);
    useEffect(function () {
        var app;
        if (!getApps().length) {
            app = initializeApp(firebaseConfig);
        }
        else {
            app = getApps()[0];
        }
        var messaging = getMessaging(app);
        Notification.requestPermission().then(function (permission) {
            if (permission === 'granted') {
                console.log('Notification permission granted.');
                getToken(messaging, { vapidKey: vapidKey }).then(function (current_token) {
                    console.log("Current token", current_token);
                })
                    .catch(function (err) {
                    console.log("Token error:", err);
                });
                onMessage(messaging, function (payload) {
                    var _a, _b, _c;
                    console.log('Message received. ', payload);
                    var notificationType = ((_a = payload.notification) === null || _a === void 0 ? void 0 : _a.title) || 'info';
                    var message = {
                        severity: 'info',
                        summary: 'Notification',
                        detail: (_b = payload.notification) === null || _b === void 0 ? void 0 : _b.body,
                        life: 3000,
                    };
                    switch (notificationType) {
                        case 'success':
                            message.severity = 'success';
                            break;
                        case 'error':
                            message.severity = 'error';
                            break;
                        case 'warn':
                            message.severity = 'warn';
                            break;
                        default:
                            message.severity = 'info';
                    }
                    (_c = toast.current) === null || _c === void 0 ? void 0 : _c.show(message);
                });
            }
            else {
                console.log('Unable to get permission to notify.');
            }
        }).catch(function (err) {
            console.error('An error occurred while retrieving token. ', err);
        });
    }, [firebaseConfig]);
    return (React.createElement(React.Fragment, null,
        React.createElement(Toast, { ref: toast }),
        children));
};
